==> glibc-2.1.3.tar.gz: glibc-2.1.3/sysdeps/unix/bsd/sigprocmask.c <==
/* Copyright (C) 1991, 1992, 1995, 1996, 1997 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the GNU C Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#include <errno.h>
#include <stddef.h>
#include <signal.h>


/* If SET is not NULL, modify the current set of blocked signals
   according to HOW, which may be SIG_BLOCK, SIG_UNBLOCK or SIG_SETMASK.
   If OSET is not NULL, store the old set of blocked signals in *OSET.  */
int
__sigprocmask (how, set, oset)
     int how;
     const sigset_t *set;
     sigset_t *oset;
{
  int mask;

  if (set != NULL)
    {
      mask = *set;
      switch (how)
	{
	case SIG_BLOCK:
	  mask = __sigblock (mask);
	  break;

	case SIG_UNBLOCK:
	  mask = __sigblock (0) & ~mask;
	  /* Fall through.  */

	case SIG_SETMASK:
	  mask = __sigsetmask (mask);
	  break;

	default:
	  __set_errno (EINVAL);
	  return -1;
	}
    }
  else
    mask = __sigblock (0);

  if (oset != NULL)
    *oset = mask;

  return 0;
}

weak_alias (__sigprocmask, sigprocmask)

==> glibc-2.3.2.tar.gz: glibc-2.3.2/sysdeps/unix/bsd/sigprocmask.c <==
/* Copyright (C) 1991, 1992, 1995, 1996, 1997 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#include <errno.h>
#include <stddef.h>
#include <signal.h>


/* If SET is not NULL, modify the current set of blocked signals
   according to HOW, which may be SIG_BLOCK, SIG_UNBLOCK or SIG_SETMASK.
   If OSET is not NULL, store the old set of blocked signals in *OSET.  */
int
__sigprocmask (how, set, oset)
     int how;
     const sigset_t *set;
     sigset_t *oset;
{
  int mask;

  if (set != NULL)
    {
      mask = *set;
      switch (how)
	{
	case SIG_BLOCK:
	  mask = __sigblock (mask);
	  break;

	case SIG_UNBLOCK:
	  mask = __sigblock (0) & ~mask;
	  /* Fall through.  */

	case SIG_SETMASK:
	  mask = __sigsetmask (mask);
	  break;

	default:
	  __set_errno (EINVAL);
	  return -1;
	}
    }
  else
    mask = __sigblock (0);

  if (oset != NULL)
    *oset = mask;

  return 0;
}

weak_alias (__sigprocmask, sigprocmask)
